@@ -628,7 +628,7 @@ class account_move(osv.osv):
 								code = getattr(tax,field_base+'base_code_id').id
 								amount = getattr(tax, field_base+'base_sign') * (line.debit + line.credit)
 								break
-						if code: 
+						if code and not (line.tax_code_id or line.tax_amount): 
 							self.pool.get('account.move.line').write(cr, uid, [line.id], {
 								'tax_code_id': code,
 								'tax_amount': amount
@@ -644,7 +644,7 @@ class account_move(osv.osv):
 					elif line.account_id.id in account:
 						code = account[line.account_id.id][0]
 						amount = account[line.account_id.id][1] * (line.debit + line.credit)
-					if code or amount:
+					if (code or amount) and not (line.tax_code_id or line.tax_amount):
 						self.pool.get('account.move.line').write(cr, uid, [line.id], {
 							'tax_code_id': code,
 							'tax_amount': amount
@@ -665,7 +665,7 @@ class account_move(osv.osv):
 					'journal_id': move.journal_id.id,
 					'period_id': move.period_id.id,
 					#'tax_code_id': False,
-					'tax_amount': False,
+					#'tax_amount': False,
 					'state': 'draft'
 				}, context, check=False)
 				ok = False
@@ -692,9 +692,6 @@ class account_bank_statement(osv.osv):
 	def _default_journal_id(self, cr, uid, context={}):
 		if context.get('journal_id', False):
 			return context['journal_id']
-		if  context.get('journal_id', False):
-			# TODO: write this
-			return False
 		return False
 
 	def _default_balance_start(self, cr, uid, context={}):
@@ -951,20 +948,17 @@ class account_move_line(osv.osv):
 
 		data['partner_id'] = partner_id
 
-		print taxes
 		for t in taxes:
 			if not taxes[t] and t[0]:
 				s=0
 				for l in move.line_id:
-					for tax in l.account_id.tax_ids:
-						taxes = self.pool.get('account.tax').compute(cr, uid, [tax.id], l.debit or l.credit, 1, False)
-						key = (l.debit and 'account_paid_id') or 'account_collected_id'
-						for t2 in taxes:
-							if (t2[key] == t[0]) and (tax.tax_code_id.id==t[1]):
-								if l.debit:
-									s += t2['amount']
-								else:
-									s -= t2['amount']
+					key = (l.debit and 'account_paid_id') or 'account_collected_id'
+					for tax in self.pool.get('account.tax').compute(cr, uid, l.account_id.tax_ids, l.debit or l.credit, 1, False):
+						if (tax[key] == t[0]) and (tax['tax_code_id']==t[1]):
+							if l.debit:
+								s += tax['amount']
+							else:
+								s -= tax['amount']
 				data['debit'] = s>0  and s or 0.0
 				data['credit'] = s<0  and -s or 0.0
 
@@ -1337,8 +1331,8 @@ class account_tax(osv.osv):
 		'type': fields.selection( [('percent','Percent'), ('fixed','Fixed'), ('none','None'), ('code','Python Code')], 'Tax Type', required=True),
 		'applicable_type': fields.selection( [('true','True'), ('code','Python Code')], 'Applicable Type', required=True),
 		'domain':fields.char('Domain', size=32, help="This field is only used if you develop your own module allowing developpers to create specific taxes in a custom domain."),
-		'account_collected_id':fields.many2one('account.account', 'Collected Tax Account'),
-		'account_paid_id':fields.many2one('account.account', 'Paid Tax Account'),
+		'account_collected_id':fields.many2one('account.account', 'Invoice Tax Account'),
+		'account_paid_id':fields.many2one('account.account', 'Refund Tax Account'),
 		'parent_id':fields.many2one('account.tax', 'Parent Tax Account', select=True),
 		'child_ids':fields.one2many('account.tax', 'parent_id', 'Childs Tax Account'),
 		'child_depend':fields.boolean('Tax on Childs', help="Indicate if the tax computation is based on the value computed for the computation of child taxes or based on the total amount."),
@@ -1389,11 +1383,7 @@ class account_tax(osv.osv):
 				res.append(tax)
 		return res
 
-	def _unit_compute(self, cr, uid, ids, price_unit, address_id=None):
-		taxes = self.browse(cr, uid, ids)
-		return self._unit_compute_br(cr, uid, taxes, price_unit, address_id)
-
-	def _unit_compute_br(self, cr, uid, taxes, price_unit, address_id=None):
+	def _unit_compute(self, cr, uid, taxes, price_unit, address_id=None):
 		taxes = self._applicable(cr, uid, taxes, price_unit, address_id)
 
 		res = []
@@ -1401,9 +1391,9 @@ class account_tax(osv.osv):
 			# we compute the amount for the current tax object and append it to the result
 			if tax.type=='percent':
 				amount = price_unit * tax.amount
-				res.append({'id':tax.id, 'name':tax.name, 'amount':amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id})
+				res.append({'id':tax.id, 'name':tax.name, 'amount':amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id, 'base_code_id': tax.base_code_id.id, 'ref_base_code_id': tax.ref_base_code_id.id, 'sequence': tax.sequence, 'base_sign': tax.base_sign, 'tax_sign': tax.tax_sign, 'ref_base_sign': tax.ref_base_sign, 'ref_tax_sign': tax.ref_tax_sign, 'price_unit': price_unit, 'tax_code_id': tax.tax_code_id.id, 'ref_tax_code_id': tax.ref_tax_code_id.id,})
 			elif tax.type=='fixed':
-				res.append({'id':tax.id, 'name':tax.name, 'amount':tax.amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id})
+				res.append({'id':tax.id, 'name':tax.name, 'amount':tax.amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id, 'base_code_id': tax.base_code_id.id, 'ref_base_code_id': tax.ref_base_code_id.id, 'sequence': tax.sequence, 'base_sign': tax.base_sign, 'tax_sign': tax.tax_sign, 'ref_base_sign': tax.ref_base_sign, 'ref_tax_sign': tax.ref_tax_sign, 'price_unit': 1, 'tax_code_id': tax.tax_code_id.id, 'ref_tax_code_id': tax.ref_tax_code_id.id,})
 			elif tax.type=='code':
 				address = address_id and self.pool.get('res.partner.address').browse(cr, uid, address_id) or None
 				localdict = {'price_unit':price_unit, 'address':address}
@@ -1414,7 +1404,17 @@ class account_tax(osv.osv):
 					'name': tax.name,
 					'amount': amount,
 					'account_collected_id': tax.account_collected_id.id,
-					'account_paid_id': tax.account_paid_id.id
+					'account_paid_id': tax.account_paid_id.id,
+					'base_code_id': tax.base_code_id.id,
+					'ref_base_code_id': tax.ref_base_code_id.id,
+					'sequence': tax.sequence,
+					'base_sign': tax.base_sign,
+					'tax_sign': tax.tax_sign,
+					'ref_base_sign': tax.ref_base_sign,
+					'ref_tax_sign': tax.ref_tax_sign,
+					'price_unit': price_unit,
+					'tax_code_id': tax.tax_code_id.id,
+					'ref_tax_code_id': tax.ref_tax_code_id.id,
 				})
 			amount2 = res[-1]['amount']
 			if len(tax.child_ids):
@@ -1424,11 +1424,11 @@ class account_tax(osv.osv):
 				else:
 					amount = amount2
 			for t in tax.child_ids:
-				parent_tax = self._unit_compute_br(cr, uid, [t], amount, address_id)
+				parent_tax = self._unit_compute(cr, uid, [t], amount, address_id)
 				res.extend(parent_tax)
 		return res
 
-	def compute(self, cr, uid, ids, price_unit, quantity, address_id=None):
+	def compute(self, cr, uid, taxes, price_unit, quantity, address_id=None):
 		"""
 		Compute tax values for given PRICE_UNIT, QUANTITY and a buyer/seller ADDRESS_ID.
 
@@ -1437,9 +1437,9 @@ class account_tax(osv.osv):
 			tax = {'name':'', 'amount':0.0, 'account_collected_id':1, 'account_paid_id':2}
 			one tax for each tax id in IDS and their childs
 		"""
-		res = self._unit_compute(cr, uid, ids, price_unit, address_id)
+		res = self._unit_compute(cr, uid, taxes, price_unit, address_id)
 		for r in res:
-			r['amount'] = round(quantity * r['amount'],2)
+			r['amount'] *= quantity
 		return res
 account_tax()
 
