@@ -232,7 +232,7 @@ class account_invoice(osv.osv):
 				for il in iml:
 					il['analytic_lines'] = [(0,0, {
 						'name': il['name'],
-						'date': time.strftime('%Y-%m-%d'),
+						'date': inv['date_invoice'],
 						'account_id': inv['project_id'],
 						'unit_amount': il['quantity'],
 						'amount': il['price'] * sign,
@@ -483,11 +483,23 @@ class account_invoice_line(osv.osv):
 		'quantity': lambda *a: 1,
 		'discount': lambda *a: 0.0
 	}
-	def product_id_change(self, cr, uid, ids, product, uom, qty=0, name='', type='out_invoice'):
+	def product_id_change(self, cr, uid, ids, product, uom, qty=0, name='', type='out_invoice', partner_id=False):
 		if not product:
 			return {'value': {'price_unit': 0.0}, 'domain':{'product_uom':[]}}
 		res = self.pool.get('product.product').browse(cr, uid, product)
-		result = {'price_unit': res.list_price, 'invoice_line_tax_id':map(lambda x: x.id, res.taxes_id)}
+		taxep=None
+		if partner_id:
+			taxep = self.pool.get('res.partner').browse(cr, uid, partner_id).property_account_tax
+		if not taxep or not taxep[0]:
+			tax_id = map(lambda x: x.id, res.taxes_id)
+		else:
+			tax_id = [taxep[0]]
+			tp = self.pool.get('account.tax').browse(cr, uid, taxep[0])
+			for t in res.taxes_id:
+				if not t.tax_group==tp.tax_group:
+					tax_id.append(t.id)
+		result = {'price_unit': res.list_price, 'invoice_line_tax_id': tax_id}
+
 		if not name:
 			result['name'] = res.name
 
@@ -515,8 +527,7 @@ class account_invoice_line(osv.osv):
 		res = []
 		tax_grouped = {}
 		tax_obj = self.pool.get('account.tax')
-#TODO: rewrite using browse instead of the manual SQL queries
-#		cr.execute('SELECT id FROM account_invoice_line WHERE invoice_id=%d', (invoice_id,))
+		ait_obj = self.pool.get('account.invoice.tax')
 		inv = self.pool.get('account.invoice').browse(cr, uid, invoice_id)
 
 		for line in inv.invoice_line:
@@ -528,80 +539,47 @@ class account_invoice_line(osv.osv):
 				'price':round(line.quantity*line.price_unit * (1.0- (line.discount or 0.0)/100.0),2),
 				'account_id':line.account_id.id
 			})
-			for tax2 in line.invoice_line_tax_id:
-				for tax in tax_obj.compute(cr, uid, [tax2.id], line.price_unit, line.quantity, inv.address_invoice_id.id):
-					tax['amount'] = tax['amount']*(1.0- (line['discount'] or 0.0)/100.0)
-					tax['sequence'] = tax2.sequence
+			for tax in tax_obj.compute(cr, uid, line.invoice_line_tax_id, (line.price_unit *(1.0-(line['discount'] or 0.0)/100.0)), line.quantity, inv.address_invoice_id.id):
+				val={}
+				val['invoice_id'] = inv.id
+				val['name'] = tax['name']
+				val['amount'] = round(tax['amount'], 2)
+				val['manual'] = False
+				val['sequence'] = tax['sequence']
+				val['base'] = tax['price_unit'] * line['quantity']
 
-					#
-					# Setting the tax account and amount for the line
-					#
-					if inv.type in ('out_invoice','out_refund'):
-						res[-1]['tax_code_id'] = tax2.base_code_id.id
-						res[-1]['tax_amount'] = line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0) * tax2.base_sign
-					else:
-						res[-1]['tax_code_id'] = tax2.ref_base_code_id.id
-						res[-1]['tax_amount'] = line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0) * tax2.ref_base_sign
-					if inv.type in ('out_refund','in_refund'):
-						res[-1]['tax_amount'] = -res[-1]['tax_amount']
+				#
+				# Setting the tax account and amount for the line
+				#
+				if inv.type in ('out_invoice','in_invoice'):
+					val['base_code_id'] = tax['base_code_id']
+					val['tax_code_id'] = tax['tax_code_id']
+					val['base_amount'] = val['base'] * tax['base_sign']
+					val['tax_amount'] = val['amount'] * tax['tax_sign']
+					val['account_id'] = tax['account_collected_id'] or line.account_id.id
+				else:
+					val['base_code_id'] = tax['ref_base_code_id']
+					val['tax_code_id'] = tax['ref_tax_code_id']
+					val['base_amount'] = val['base'] * tax['ref_base_sign']
+					val['tax_amount'] = val['amount'] * tax['ref_tax_sign']
+					val['account_id'] = tax['account_paid_id'] or line.account_id.id
 
-					if inv.type in ('out_invoice','out_refund'):
-						tax['account_id'] = tax['account_collected_id'] or line.account_id.id
-					else:
-						tax['account_id'] = tax['account_paid_id'] or line.account_id.id
-					#
-					# Revoir la cl: tax.id ?
-					#
-					key = (res[-1]['tax_code_id'], tax['account_id'])
-					if not key in tax_grouped:
-						tax_grouped[key] = tax
-						tax_grouped[key]['base'] = line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0)
-					else:
-						tax_grouped[key]['amount'] += tax['amount']
-						tax_grouped[key]['base'] += line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0)
+				res[-1]['tax_code_id'] = val['base_code_id']
+				res[-1]['tax_amount'] = val['base_amount']
+
+				key = (val['tax_code_id'], val['base_code_id'], val['account_id'])
+				if not key in tax_grouped:
+					tax_grouped[key] = val
+				else:
+					tax_grouped[key]['amount'] += val['amount']
+					tax_grouped[key]['base'] += val['base']
+					tax_grouped[key]['base_amount'] += val['base_amount']
+					tax_grouped[key]['tax_amount'] += val['tax_amount']
 		# delete automatic tax lines for this invoice
 		cr.execute("DELETE FROM account_invoice_tax WHERE NOT manual AND invoice_id=%d", (invoice_id,))
-		self.move_line_tax_create(cr, uid, inv, tax_grouped, context)
-		return res
-
-	def move_line_tax_create(self, cr, uid, inv,  tax_grouped, context={}):
-		
-		# (re)create them
-		ait = self.pool.get('account.invoice.tax')
 		for t in tax_grouped.values():
-			tax = self.pool.get('account.tax').browse(cr, uid, t['id'])
-			val = {
-				'invoice_id':inv.id,
-				'name':t['name'],
-				'account_id':t['account_id'],
-				'amount':t['amount'],
-				'manual':False,
-				'sequence':t['sequence'],
-				'base': t['base'],
-			}
-			if inv.type in ('out_invoice','out_refund'):
-				val.update({
-					'base_code_id': tax.base_code_id.id or False,
-					'tax_code_id': tax.tax_code_id.id or False,
-					'base_amount': tax.base_sign * t['base'],
-					'tax_amount': tax.tax_sign * t['amount']
-				})
-			elif inv.type in ('in_invoice','in_refund'):
-				val.update({
-					'base_code_id': tax.ref_base_code_id.id or False,
-					'tax_code_id': tax.ref_tax_code_id.id or False,
-					'base_amount': tax.ref_base_sign * t['base'],
-					'tax_amount': tax.ref_tax_sign * t['amount']
-				})
-			if inv.type in ('out_refund','in_refund'):
-				val.update({
-					'base_amount': -val['base_amount'],
-					'tax_amount': -val['tax_amount']
-				})
-
-			ait.create(cr, uid, val)
-			#ait.create(cr, uid, {'invoice_id':invoice_id, 'name':t['name'], 'account_id':t['account_id'], 'amount':t['amount'], 'manual':False, 'sequence':t['sequence'], 'base':t['base']})
-		return True
+			ait_obj.create(cr, uid, t)
+		return res
 
 	#
 	# Set the tax field according to the account and the partner
