@@ -26,13 +26,13 @@
 #
 ##############################################################################
 
-import sql_db
+import pooler
 import time
 from report import report_sxw
 
 class account_analytic_year_to_date_check(report_sxw.rml_parse):
-	def __init__(self, name, table, rml):
-		super(account_analytic_year_to_date_check, self).__init__(name, table, rml)
+	def __init__(self, cr, uid, name, context):
+		super(account_analytic_year_to_date_check, self).__init__(cr, uid, name, context)
 		self.localcontext.update( {
 			'time': time,
 			'start_date': self._get_start_date,
@@ -73,12 +73,12 @@ class account_analytic_year_to_date_check(report_sxw.rml_parse):
 			(ac,) = self.cr.fetchone()
 			ac = ac or 0.0
 
-			r['gen_debit'] = gd
-			r['gen_credit'] = gc
-			r['ana_debit'] = ad
-			r['ana_credit'] = ac
-			r['delta_debit'] = gd - ad or ''
-			r['delta_credit'] = gc - ac or ''
+			r['gen_debit'] = '%.2f' % gd
+			r['gen_credit'] = '%.2f' % gc
+			r['ana_debit'] = '%.2f' % ad
+			r['ana_credit'] = '%.2f' % ac
+			r['delta_debit'] = '%.2f' % (gd - ad) or ''
+			r['delta_credit'] = '%.2f' % (gc - ac) or ''
 		return periods
 
 
