@@ -29,27 +29,10 @@ import time
 from report import report_sxw
 
 class account_invoice(report_sxw.rml_parse):
-	def __init__(self, cr, uid, context):
-		super(account_invoice, self).__init__(cr, uid, context)
+	def __init__(self, cr, uid, name, context):
+		super(account_invoice, self).__init__(cr, uid, name, context)
 		self.localcontext.update({
 			'time': time,
-			'get_name': self._get_name,
 		})
-
-	def _get_name(self, invoice_obj):
-		name = ""
-		if invoice_obj.state == 'draft':
-			name += "Draft "
-		elif invoice_obj.state == 'proforma':
-			name += "Pro-Forma "
-		if invoice_obj.type in ('out_invoice', 'in_invoice'):
-			if name == "":
-				name += "Invoice "
-			else:
-				name += "invoice "
-		else:
-			name += "refund "
-		return name
-
 report_sxw.report_sxw('report.account.invoice', 'account.invoice', 'addons/account/report/invoice.rml', parser=account_invoice)
 
