@@ -62,7 +62,12 @@ def _trans_reconcile(self, cr, uid, data, context):
 def _wo_check(self, cr, uid, data, context):
 	pool = pooler.get_pool(cr.dbname)
 	invoice = pool.get('account.invoice').browse(cr, uid, data['id'], context)
-	if data['form']['amount'] == invoice.amount_total:
+	company_currency = pool.get('res.users').browse(cr, uid, uid).company_id.currency_id.id
+	if invoice.currency_id.id != company_currency:
+		amount = round(pool.get('res.currency').compute(cr, uid, invoice.currency_id.id, company_currency, invoice.amount_total), 2)
+	else:
+		amount = invoice.amount_total
+	if data['form']['amount'] == amount:
 		return 'reconcile'
 	return 'addendum'
 
@@ -86,7 +91,14 @@ def _get_period(self, cr, uid, data, context={}):
 	if len(ids):
 		period_id = ids[0]
 	invoice = pool.get('account.invoice').browse(cr, uid, data['id'], context)
-	return {'period_id': period_id, 'amount': invoice.amount_total}
+	if invoice.state == 'draft':
+		raise wizard.except_wizard('Error !', 'Can not pay draft invoice.')
+	company_currency = pool.get('res.users').browse(cr, uid, uid).company_id.currency_id.id
+	if invoice.currency_id.id != company_currency:
+		amount = round(pool.get('res.currency').compute(cr, uid, invoice.currency_id.id, company_currency, invoice.amount_total), 2)
+	else:
+		amount = invoice.amount_total
+	return {'period_id': period_id, 'amount': amount}
 
 class wizard_pay_invoice(wizard.interface):
 	states = {
