@@ -29,6 +29,7 @@ import wizard
 import netsvc
 import time
 import osv
+import pooler
 
 _transaction_form = '''<?xml version="1.0"?>
 <form string="Reconciliation">
@@ -50,7 +51,7 @@ _transaction_fields = {
 
 def _trans_rec_get(self, cr, uid, data, context={}):
 	service = netsvc.LocalService("object_proxy")
-	res = filter(lambda x: not x['reconcile_id'], service.execute(uid, 'account.move.line', 'read', data['ids']))
+	res = filter(lambda x: not x['reconcile_id'], service.execute(cr.dbname, uid, 'account.move.line', 'read', data['ids']))
 	credit = debit = 0
 	account_id = False
 	for trans in res:
@@ -65,7 +66,7 @@ def _trans_rec_reconcile(self, cr, uid, data, context):
 	account_id = form.get('writeoff_acc_id', False)
 	period_id = form.get('period_id', False)
 	journal_id = form.get('journal_id', False)
-	service.execute(uid, 'account.move.line', 'reconcile', data['ids'], 'manual', account_id, period_id, journal_id, context)
+	service.execute(cr.dbname, uid, 'account.move.line', 'reconcile', data['ids'], 'manual', account_id, period_id, journal_id, context)
 	return {}
 
 def _wo_check(self, cr, uid, data, context):
@@ -88,7 +89,7 @@ _transaction_add_fields = {
 }
 
 def _trans_rec_addendum(self, cr, uid, data, context={}):
-	pool = osv.osv.osv_pools
+	pool = pooler.get_pool(cr.dbname)
 	ids = pool.get('account.period').find(cr, uid, context=context)
 	period_id = False
 	if len(ids):
