@@ -26,15 +26,15 @@
 ##############################################################################
 
 import wizard
-from osv.osv import osv_pools
+import pooler
 
 def _trans_unrec(self, cr, uid, data, context):
-	recs = osv_pools.get('account.move.line').read(cr, uid, data['ids'], ['reconcile_id',])
+	recs = pooler.get_pool(cr.dbname).get('account.move.line').read(cr, uid, data['ids'], ['reconcile_id',])
 	recs = filter(lambda x: x['reconcile_id'], recs)
 	rec_ids = [rec['reconcile_id'][0] for rec in recs]
 	if len(rec_ids):
 		cr.execute('update account_move_line set state=\'valid\' where reconcile_id in ('+','.join(map(str,rec_ids))+')')
-		osv_pools.get('account.move.reconcile').unlink(cr, uid, rec_ids)
+		pooler.get_pool(cr.dbname).get('account.move.reconcile').unlink(cr, uid, rec_ids)
 	return {}
 
 class wiz_unreconcile(wizard.interface):
