@@ -3,11 +3,13 @@
 	"version" : "1.0",
 	"depends" : ["account"],
 	"author" : "Tiny",
+	"description": "Modules to automate letters for unpaid invoices, with multi-level recalls",
 	"website" : "http://tinyerp.com/module_account.html",
 	"category" : "Generic Modules/Accounting",
 	"init_xml" : [],
 	"demo_xml" : ["followup_demo.xml"],
 	"update_xml" : ["followup_view.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
 
