@@ -29,21 +29,13 @@
 import time
 import ir
 
-import sql_db
+import pooler
 from osv import osv
 from report import report_sxw
 
-def find(value, list, key):
-	for dico in list:
-		value_key = dico.get(key, None)
-		if value == value_key:
-			return dico
-		elif isinstance(value_key, tuple) and value in value_key:
-			return dico
-
 class report_rappel(report_sxw.rml_parse):
-	def __init__(self, name, table, rml):
-		super(report_rappel, self).__init__(name, table, rml)
+	def __init__(self, cr, uid, name, context):
+		super(report_rappel, self).__init__(cr, uid, name, context)
 		self.localcontext.update( {
 			'time' : time,
 			'ids_to_objects': self._ids_to_objects,
@@ -52,20 +44,18 @@ class report_rappel(report_sxw.rml_parse):
 		})
 
 	def _ids_to_objects(self, partners_ids):
-		cr = sql_db.db.cursor()
-		toto = osv.osv_pools.get('res.partner').browse(self.cr, self.uid, partners_ids)
-		cr.close()
+		toto = pooler.get_pool(self.cr.dbname).get('res.partner').browse(self.cr, self.uid, partners_ids)
 		return toto
 
 	def _adr_get(self, partner, type):
-		res_partner = osv.osv_pools.get('res.partner')
-		res_partner_address = osv.osv_pools.get('res.partner.address')
+		res_partner = pooler.get_pool(self.cr.dbname).get('res.partner')
+		res_partner_address = pooler.get_pool(self.cr.dbname).get('res.partner.address')
 		adr = res_partner.address_get(self.cr, self.uid, [partner.id], [type])[type]
 		return res_partner_address.read(self.cr, self.uid, [adr])[0]
 
 	def _lines_get(self, partner):
 		acc = partner.property_account_receivable[0]
-		moveline_obj = osv.osv_pools.get('account.move.line')
+		moveline_obj = pooler.get_pool(self.cr.dbname).get('account.move.line')
 		movelines = moveline_obj.search(self.cr, self.uid, [('partner_id','=',partner.id), ('account_id','=',acc), ('state','=','valid')])
 		movelines = moveline_obj.read(self.cr, self.uid, movelines)
 		return movelines
