@@ -87,6 +87,8 @@ class ir_model_access(osv.osv):
 	}
 	def check(self, cr, uid, model_name, mode='read'):
 		assert mode in ['read','write','create'], 'Invalid access mode for security'
+		if uid==1:
+			return True
 		
 		# fetch the list of rules for this "permission type" on this model
 		cr.execute('select group_id, perm_'+mode+' from ir_model_access a left join ir_model m on (a.model_id=m.id) where m.model=%s', (model_name,))
@@ -255,19 +257,15 @@ class ir_model_data(osv.osv):
 		cr.commit()
 		for (model,id) in self.unlink_mark.keys():
 			if self.pool.get(model):
-				print 'Deleting %s@%s' % (id, model),
+				logger = netsvc.Logger()
+				logger.notifyChannel('init', netsvc.LOG_INFO, 'Deleting %s@%s' % (id, model))
 				try:
 					self.pool.get(model).unlink(cr, uid, [id])
 					if self.unlink_mark[(model,id)]:
 						self.unlink(cr, uid, [self.unlink_mark[(model,id)]])
 					cr.commit()
-					print '... ok'
 				except:
-					print '... ko'
-					print '-'*60
-					print 'WARNING: Could not delete id', id, 'of model', model
-					print '\tThere should be some relation that points to this resource'
-					print '\tYou should manually fix this and restart --update=module'
+					logger.notifyChannel('init', netsvc.LOG_ERROR, 'Could not delete id: %d of model %s\tThere should be some relation that points to this resource\tYou should manually fix this and restart --update=module' % (id, model))
 		return True
 ir_model_data()
 
