@@ -33,7 +33,7 @@ import netsvc
 class wizard_info_get(wizard.interface):
 	def _update_module(self, cr, uid, data, context):
 		service = netsvc.LocalService("object_proxy")
-		service.execute(uid, 'ir.module.module', 'info_get', data['ids'])
+		service.execute(cr.dbname, uid, 'ir.module.module', 'info_get', data['ids'])
 		return {}
 
 	states = {
