@@ -34,7 +34,7 @@ class res_company(osv.osv):
 
 	_columns = {
 		'name': fields.char('Company Name', size=64, required=True),
-		'parent_id': fields.many2one('res.company', 'Parent Company'),
+		'parent_id': fields.many2one('res.company', 'Parent Company', select=True),
 		'child_ids': fields.one2many('res.company', 'parent_id', 'Childs Company'),
 		'partner_id': fields.many2one('res.partner', 'Partner', required=True),
 		'rml_header1': fields.char('Report Header', size=200),
