@@ -1,7 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 TINY SPRL. (http://tiny.be) All Rights Reserved.
-#                    Fabien Pinckaers <fp@tiny.Be>
+# Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -34,7 +33,7 @@ import random
 import StringIO
 
 import tools
-import sql_db
+import pooler
 
 from report.render import render 
 from report.interface import report_int
@@ -54,12 +53,8 @@ class external_pdf(render):
 		return self.pdf
 
 class report_custom(report_int):
-	def __init__(self, name):
-		report_int.__init__(self, name)
-
-	def create(self, uid, ids, datas, context={}):
+	def create(self, cr, uid, ids, datas, context={}):
 		assert len(ids), 'You should provide some ids!'
-		cr = sql_db.db.cursor()
 		responsible_data = {}
 		responsible_names = {}
 		data = []
@@ -68,7 +63,6 @@ class report_custom(report_int):
 
 		cr.execute('select probability, planned_revenue, planned_cost, user_id, res_users.name as name from crm_case left join res_users on (crm_case.user_id=res_users.id) where crm_case.id in ('+','.join(map(str,ids))+') order by user_id')
 		res = cr.dictfetchall()
-		cr.close()
 
 		for row in res:
 			proba = row['probability'] or 0
