@@ -4,9 +4,11 @@
 	"author" : "Tiny",
 	"category" : "Generic Modules/Human Resources",
 	"website" : "http://tinyerp.com/module_hr.html",
-	"depends" : ["base", "account", "hr"],
+	"description": "Timesheet system, completly integrated with the cost accounting module. It allows you to set up a management by affair.",
+	"depends" : ["account", "hr"],
 	"init_xml" : ["hr_timesheet_data.xml"],
-	"demo_xml" : ["hr_timesheet_demo.xml"],
+	"demo_xml" : ["hr_timesheet_demo.xml","hr.analytic.timesheet.csv"],
 	"update_xml" : ["hr_timesheet_view.xml", "hr_timesheet_report.xml","hr_timesheet_wizard.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
