@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: user_timesheet.py 4525 2006-11-10 08:59:57Z ced $
+# $Id: user_timesheet.py 5644 2007-02-15 10:55:46Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -68,7 +68,7 @@ class report_custom(report_rml):
 		
 		xml = '''
 		<time-element date="%s">
-			<amount>%s</amount>
+			<amount>%.2f</amount>
 		</time-element>
 		'''
 		account_xml = []
