@@ -40,20 +40,20 @@ _line_fields = {
 
 def _paragraph_find(self, cr, uid, data, context):
 	service = netsvc.LocalService("object_proxy")
-	type_id = service.execute(uid, 'letter.letter', 'read', [data['id']], ['type_id'])[0]['type_id'][0]
-	para_ids = service.execute(uid, 'letter.letter.type', 'read', [type_id], ['paragraph_ids'])[0]['paragraph_ids']
+	type_id = service.execute(cr.dbname, uid, 'letter.letter', 'read', [data['id']], ['type_id'])[0]['type_id'][0]
+	para_ids = service.execute(cr.dbname, uid, 'letter.letter.type', 'read', [type_id], ['paragraph_ids'])[0]['paragraph_ids']
 	return {'paragraph_lines': para_ids}
 
 def _paragraph_add(self, cr, uid, data, context):
 	service = netsvc.LocalService("object_proxy")
-	lines = service.execute(uid, 'letter.paragraph', 'read', data['form']['paragraph_lines'][0][2], ['name','sequence','content','type_id'])
+	lines = service.execute(cr.dbname, uid, 'letter.paragraph', 'read', data['form']['paragraph_lines'][0][2], ['name','sequence','content','type_id'])
 	adding = []
 	for line in lines:
 		line['letter_id'] = data['id']
 		line['type_id'] = line['type_id'][0]
 		del line['id']
 		adding.append((0,0,line))
-	service.execute(uid, 'letter.letter', 'write', [data['id']], {'paragraph_ids': adding})
+	service.execute(cr.dbname, uid, 'letter.letter', 'write', [data['id']], {'paragraph_ids': adding})
 	return {}
 
 class paragraph_load(wizard.interface):
