@@ -49,10 +49,10 @@ email_send_fields = {
 
 def _email_send(self, cr, uid, data, context):
 	service = netsvc.LocalService("object_proxy")
-	res = service.execute(uid, 'campaign.partner', 'read', data['ids'], ['partner_id'])
+	res = service.execute(cr.dbname, uid, 'campaign.partner', 'read', data['ids'], ['partner_id'])
 	partners_id = map(lambda r: r['partner_id'][0], res)
 	form = data['form']
-	nbr = service.execute(uid, 'res.partner', 'email_send', partners_id, form['from'], form['subject'], form['body'], form['on_error'])
+	nbr = service.execute(cr.dbname, uid, 'res.partner', 'email_send', partners_id, form['from'], form['subject'], form['body'], form['on_error'])
 	return {'email_sent': nbr}
 
 class part_email(wizard.interface):
