@@ -33,13 +33,14 @@ from schedulers import _procure_orderpoint_confirm
 import threading
 
 parameter_form = '''<?xml version="1.0"?>
-<form title="Scheduler Parameters" colspan="4">
+<form string="Scheduler Parameters" colspan="4">
 	<separator string="Time (days)" colspan="4"/>
 	<field name="po_lead"/>
 	<field name="picking_lead"/>
 	<field name="schedule_cycle"/>
 	<field name="po_cycle"/>
 	<field name="security_lead"/>
+	<field name="automatic" />
 	<separator string="Control" colspan="4"/>
 	<field name="user_id"/>
 </form>'''
@@ -50,16 +51,17 @@ parameter_fields = {
 	'po_lead': {'string':'PO Lead Time', 'type':'float', 'required':True, 'default': lambda *a: 1.0},
 	'security_lead': {'string':'Security Days', 'type':'float', 'required':True, 'default': lambda *a: 50.0},
 	'picking_lead': {'string':'Picking Lead Time', 'type':'float', 'required':True, 'default': lambda *a: 1.0},
+	'automatic': {'string': 'Automatic orderpoint', 'type': 'boolean', 'help': 'Triggers an automatic procurement for all products that have a virtual stock under 0.', 'default': lambda *a: False},
 	'user_id': {'string':'Send Result To', 'type':'many2one', 'relation':'res.users', 'default': lambda uid,data,state: uid},
 }
 
-def _procure_calculation_all(self, uid, data, context):
-	_procure_confirm(self, uid, data, context)
-	_procure_orderpoint_confirm(self, uid, data, context)
+def _procure_calculation_all(self, db_name, uid, data, context):
+	_procure_confirm(self, db_name, uid, data, context)
+	_procure_orderpoint_confirm(self, db_name, uid, data, context)
 	return {}
 
 def _procure_calculation(self, cr, uid, data, context):
-	threaded_calculation = threading.Thread(target=_procure_calculation_all, args=(self, uid, data, context))
+	threaded_calculation = threading.Thread(target=_procure_calculation_all, args=(self, cr.dbname, uid, data, context))
 	threaded_calculation.start()
 	return {}
 
