@@ -3,7 +3,7 @@
 	"version":"1.0",
 	"author":"Tiny",
 	"category":"Profile",
-	"depends":["base", "account", "report_analytic_line" ],
+	"depends":["account_tax_include", "account", "report_analytic_line" ],
 	"demo_xml":[],
 	"update_xml":[],
 	"active":False,
