@@ -57,9 +57,8 @@ class purchase_order(osv.osv):
 		for order in self.browse(cr, uid, ids):
 			val = 0.0
 			for line in order.order_line:
-				for tax in line.taxes_id:
-					for c in self.pool.get('account.tax').compute(cr, uid, [tax.id], line.price_unit, line.product_qty, order.partner_address_id.id):
-						val+=c['amount']
+				for c in self.pool.get('account.tax').compute(cr, uid, line.taxes_id, line.price_unit, line.product_qty, order.partner_address_id.id):
+					val+=round(c['amount'], 2)
 			res[order.id]=round(val,2)
 		return res
 
@@ -206,7 +205,7 @@ class purchase_order(osv.osv):
 				'origin': o.name,
 				'invoice_line': il,
 			}
-			inv_id = self.pool.get('account.invoice').create(cr, uid, inv)
+			inv_id = self.pool.get('account.invoice').create(cr, uid, inv, {'type':'in_invoice'})
 
 			self.write(cr, uid, [o.id], {'invoice_id': inv_id})
 			res = inv_id
