@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: wizard_group.py 4522 2006-11-09 16:02:35Z pinky $
+# $Id: wizard_group.py 5190 2007-01-10 06:30:51Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -59,6 +59,9 @@ def _mergeOrders(self, cr, uid, data, context):
 		list_key = []
 		for field in fields:
 			field_val = getattr(br, field)
+			if field in ('product_id','move_dest_id'):
+				if not field_val:
+					field_val = False
 			if isinstance(field_val, browse_record):
 				field_val = field_val.id
 			elif isinstance(field_val, list):
