@@ -7,6 +7,15 @@
 	"category" : "Generic Modules/Sales & Purchases",
 	"init_xml" : [],
 	"demo_xml" : ["sale_demo.xml"],
-	"update_xml" : ["sale_workflow.xml", "sale_sequence.xml", "sale_data.xml","sale_view.xml", "sale_report.xml", "sale_wizard.xml", "sale_shortcut.xml"],
-	"active": True
+	"update_xml" : [
+		"sale_workflow.xml",
+		"sale_sequence.xml",
+		"sale_data.xml",
+		"sale_view.xml",
+		"sale_report.xml",
+		"sale_wizard.xml",
+		"stock_view.xml"
+	],
+	"active": False,
+	"installable": True
 }
