@@ -77,9 +77,8 @@ class sale_order(osv.osv):
 		for order in self.browse(cr, uid, ids):
 			val = 0.0
 			for line in order.order_line:
-				for tax in line.tax_id:
-					for c in self.pool.get('account.tax').compute(cr, uid, [tax.id], line.price_unit * (1-(line.discount or 0.0)/100.0), line.product_uom_qty, order.partner_invoice_id.id):
-						val += round(c['amount'], 2)
+				for c in self.pool.get('account.tax').compute(cr, uid, line.tax_id, line.price_unit * (1-(line.discount or 0.0)/100.0), line.product_uos_qty, order.partner_invoice_id.id):
+					val += round(c['amount'], 2)
 			res[order.id]=round(val,2)
 		return res
 
@@ -236,6 +235,12 @@ class sale_order(osv.osv):
 			if created_lines:
 				invoices.setdefault(o.partner_id.id, []).append((o, created_lines))
 
+		if not invoices:
+			for o in self.browse(cr, uid, ids):
+				for i in o.invoice_ids:
+					if i.state == 'draft':
+						return i.id
+
 		for val in invoices.values():
 			if grouped:
 				res = make_invoice(val[0][0], reduce(lambda x,y: x + y, [l for o,l in val], []))
@@ -250,6 +255,20 @@ class sale_order(osv.osv):
 					cr.execute('insert into sale_order_invoice_rel (order_id,invoice_id) values (%d,%d)', (o.id, res))
 		return res
 
+	def action_invoice_cancel(self, cr, uid, ids, context={}):
+		for sale in self.browse(cr, uid, ids):
+			for line in sale.order_line:
+				invoiced=False
+				for iline in line.invoice_lines:
+					if iline.invoice_id and iline.invoice_id.state == 'cancel':
+						continue
+					else:
+						invoiced=True
+				self.pool.get('sale.order.line').write(cr, uid, [line.id], {'invoiced': invoiced})
+		self.write(cr, uid, ids, {'state':'invoice_except', 'invoice_id':False})
+		return True
+
+
 	def action_cancel(self, cr, uid, ids, context={}):
 		ok = True
 		for sale in self.browse(cr, uid, ids):
@@ -490,7 +509,7 @@ class sale_order_line(osv.osv):
 		'date_planned': fields.date('Date Promised', required=True),
 		'product_id': fields.many2one('product.product', 'Product', domain=[('sale_ok','=',True)], change_default=True, relate=True),
 		'invoice_lines': fields.many2many('account.invoice.line', 'sale_order_line_invoice_rel', 'order_line_id','invoice_id', 'Invoice Lines', readonly=True),
-		'invoiced': fields.boolean('Paid', readonly=True, select=True),
+		'invoiced': fields.boolean('Invoiced', readonly=True, select=True),
 		'procurement_id': fields.many2one('mrp.procurement', 'Procurement'),
 		'price_unit': fields.float('Unit Price', required=True),
 		'price_net': fields.function(_amount_line_net, method=True, string='Net Price'),
