@@ -31,22 +31,20 @@ from osv import osv, fields
 class stock_move(osv.osv):
 	_inherit = 'stock.move'
 	_columns = {
-		'sale_line_id': fields.many2one('sale.order.line', 'Sale Order Line', ondelete='set null'),
+		'sale_line_id': fields.many2one('sale.order.line', 'Sale Order Line', ondelete='set null', select=True),
 	}
 	_defaults = {
-#FIXME: this is BAD !
-		'sale_line_id': lambda *a:0
+		'sale_line_id': lambda *a:False
 	}
 stock_move()
 
 class stock_picking(osv.osv):
 	_inherit = 'stock.picking'
 	_columns = {
-		'sale_id': fields.many2one('sale.order', 'Sale Order', ondelete='set null'),
+		'sale_id': fields.many2one('sale.order', 'Sale Order', ondelete='set null', select=True),
 	}
 	_defaults = {
-#FIXME: this is BAD !
-		'sale_id': lambda *a: 0
+		'sale_id': lambda *a: False
 	}
 stock_picking()
 
