@@ -7,5 +7,6 @@
 	"depends" : ["base", "sale"],
 	"init_xml" : [],
 	"update_xml" : ['sale_view.xml'],
-	"active": False
+	"active": False,
+	"installable": False
 }
