@@ -42,7 +42,7 @@ sale_form = """<?xml version="1.0"?>
 
 sale_fields = {
 	'name' : {'string' : 'Order name', 'type': 'char'},
-	'partner_id' : {'string':'Suplier', 'relation':'res.partner', 'type':'many2one'},
+	'partner_id' : {'string':'Supplier', 'relation':'res.partner', 'type':'many2one'},
 }
 
 class make_sale(wizard.interface):
