@@ -515,7 +515,10 @@ class stock_picking(osv.osv):
 			res[p.id]= invoice_id
 
 			for line in p.move_lines:
-				tax_ids = map(lambda x: x.id, line.product_id.taxes_id)
+				if line.sale_line_id:
+					tax_ids = map(lambda x: x.id, line.sale_line_id.tax_id)
+				else:
+					tax_ids = map(lambda x: x.id, line.product_id.taxes_id)
 				a =  line.product_id.product_tmpl_id.property_account_income
 				if not a:
 					a = line.product_id.categ_id.property_account_income_categ
@@ -535,7 +538,7 @@ class stock_picking(osv.osv):
 				})
 				if line.sale_line_id:
 					self.pool.get('sale.order.line').write(cr, uid, [line.sale_line_id.id], {
-						'invoice_line_ids': [(6, 0, [iline_id])]
+						'invoice_lines': [(6, 0, [iline_id])]
 					})
 
 			self.pool.get('stock.picking').write(cr, uid, [p.id], {'invoice_state': 'invoiced'})
@@ -690,10 +693,12 @@ class stock_move(osv.osv):
 	#
 	def check_assign(self, cr, uid, ids, context={}):
 		done = []
+		count=0
 		pickings = {}
 		for move in self.browse(cr, uid, ids):
 			if move.product_id.type == 'consu':
 				done.append(move.id)
+				pickings[move.picking_id.id] = 1
 				continue
 			if move.state in ('confirmed','waiting'):
 				res = self.pool.get('stock.location')._product_reserve(cr, uid, [move.location_id.id], move.product_id.id, move.product_qty, {'uom': move.product_uom.id})
@@ -708,13 +713,15 @@ class stock_move(osv.osv):
 						move_id = self.copy(cr, uid, move.id, {'product_qty':r[0], 'location_id':r[1]})
 						done.append(move_id)
 						#cr.execute('insert into stock_move_history_ids values (%d,%d)', (move.id,move_id))
-
 		if done:
+			count += len(done)
 			self.write(cr, uid, done, {'state':'assigned'})
+
+		if count:
 			for pick_id in pickings:
 				wf_service = netsvc.LocalService("workflow")
 				wf_service.trg_write(uid, 'stock.picking', pick_id, cr)
-		return len(done)
+		return count
 
 	#
 	# Cancel move => cancel others move and pickings
