@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: wizard_partial_picking.py 4058 2006-09-06 13:50:25Z pinky $
+# $Id: wizard_partial_picking.py 4468 2006-11-06 12:30:42Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -30,6 +30,7 @@
 import time
 import netsvc
 from tools.misc import UpdateableStr
+import pooler
 
 import wizard
 from osv import osv
@@ -46,7 +47,7 @@ def make_default(val):
 	return fct
 
 def _get_moves(self, cr, uid, data, context):
-	pick_obj = osv.osv_pools.get('stock.picking')
+	pick_obj = pooler.get_pool(cr.dbname).get('stock.picking')
 	pick = pick_obj.browse(cr, uid, [data['id']])[0]
 	res = {}
 	_moves_fields.clear()
@@ -63,24 +64,12 @@ def _get_moves(self, cr, uid, data, context):
 	return res
 
 def _do_split(self, cr, uid, data, context):
-	move_obj = osv.osv_pools.get('stock.move')
-	pick_obj = osv.osv_pools.get('stock.picking')
+	move_obj = pooler.get_pool(cr.dbname).get('stock.move')
+	pick_obj = pooler.get_pool(cr.dbname).get('stock.picking')
 	pick = pick_obj.browse(cr, uid, [data['id']])[0]
 	new_picking = None
 	new_moves = []
 
-#	# Iterate on the moves, copying them if necessary and setting them to the
-#	# right quantity
-#	for move in move_obj.browse(cr, uid, data['form'].get('moves',[])):
-#		# Check the number of product received/sent
-#		if move.product_qty != data['form']['move%s' % move.id]:
-#			if not new_picking:
-#				new_picking = pick_obj.copy(cr, uid, pick.id, {'name' : '%s (splitted)' % pick.name, 'move_lines' : [], 'state':'draft'})
-#			new_obj = move_obj.copy(cr, uid, move.id, {'product_qty' : data['form']['move%s' % move.id], 'picking_id' : new_picking, 'state': move.state, 'move_dest_id': False})
-#			new_moves.append(new_obj)
-#			move_obj.write(cr, uid, [move.id], {'product_qty' : move.product_qty - data['form']['move%s' % move.id]})
-	
-
 	complete, too_many, too_few = [], [], []
 	for move in move_obj.browse(cr, uid, data['form'].get('moves',[])):
 		if move.product_qty == data['form']['move%s' % move.id]:
@@ -93,13 +82,13 @@ def _do_split(self, cr, uid, data, context):
 	for move in too_few:
 		if not new_picking:
 			new_picking = pick_obj.copy(cr, uid, pick.id, {'name' : '%s (splitted)' % pick.name, 'move_lines' : [], 'state':'draft'})
-		new_obj = move_obj.copy(cr, uid, move.id, {'product_qty' : data['form']['move%s' % move.id], 'picking_id' : new_picking, 'state': move.state, 'move_dest_id': False})
-		move_obj.write(cr, uid, [move.id], {'product_qty' : move.product_qty - data['form']['move%s' % move.id]})
+		new_obj = move_obj.copy(cr, uid, move.id, {'product_qty' : data['form']['move%s' % move.id], 'product_uos_qty':data['form']['move%s' % move.id], 'picking_id' : new_picking, 'state': move.state, 'move_dest_id': False})
+		move_obj.write(cr, uid, [move.id], {'product_qty' : move.product_qty - data['form']['move%s' % move.id], 'product_uos_qty':move.product_qty - data['form']['move%s' % move.id]})
 
 	if new_picking:
 		move_obj.write(cr, uid, [c.id for c in complete], {'picking_id': new_picking})
 		for move in too_many:
-			move_obj.write(cr, uid, [move.id], {'product_qty' : data['form']['move%s' % move.id], 'picking_id': new_picking})
+			move_obj.write(cr, uid, [move.id], {'product_qty' : data['form']['move%s' % move.id],'product_uos_qty':data['form']['move%s' % move.id] , 'picking_id': new_picking})
 	
 	# At first we confirm the new picking (if necessary)
 	wf_service = netsvc.LocalService("workflow")
