@@ -28,6 +28,7 @@
 
 import wizard
 from osv import osv
+import pooler
 
 arch = '''<?xml version="1.0"?>
 <form string="Lots lines">
@@ -42,15 +43,15 @@ def _get_value(self, cr, uid, data, context):
 	cr.execute("select l.id,l.name,l.product_uom,l.product_qty,l.serial,l.tracking,l.reservation_id,l.product_id,r.state from stock_lot_line l left join stock_reservation r on (l.reservation_id=r.id) where r.state='assigned' and r.picking_id=%d", (data['id'],))
 	records = cr.dictfetchall()
 	ids_products = [x['product_id'] for x in records]
-	prods = dict(osv.osv_pools.get('product.product').name_get(cr, uid, ids_products))
+	prods = dict(pooler.get_pool(cr.dbname).get('product.product').name_get(cr, uid, ids_products))
 	ids_new = []
 	for record in records:
-		ids_new.append( osv.osv_pools.get('stock.picking.lot.line').create(cr, uid, {'name': prods.get(record['product_id'],'Unknown'),'product_id':record['product_id'],  'product_uom':record['product_uom'], 'product_qty':record['product_qty'],'serial':record['serial'],'tracking':record['tracking'],'reservation_id':record['reservation_id'],'picking_id':data['id'],'lot_line_id':record['id'],'state':record['state']}) )
+		ids_new.append( pooler.get_pool(cr.dbname).get('stock.picking.lot.line').create(cr, uid, {'name': prods.get(record['product_id'],'Unknown'),'product_id':record['product_id'],  'product_uom':record['product_uom'], 'product_qty':record['product_qty'],'serial':record['serial'],'tracking':record['tracking'],'reservation_id':record['reservation_id'],'picking_id':data['id'],'lot_line_id':record['id'],'state':record['state']}) )
 	return {'lot_lines':ids_new}
 
 def _split_line(self, cr, uid, data, context):
 	service = netsvc.LocalService("object_proxy")
-	quantity = service.execute(uid, 'stock.lot.line', '_split', data['id'], data['form']['quantity'], data['form']['serial'], data['form']['tracking'])
+	quantity = service.execute(cr.dbname, uid, 'stock.lot.line', '_split', data['id'], data['form']['quantity'], data['form']['serial'], data['form']['tracking'])
 	return {}
 
 class stock_picking_make(wizard.interface):
