@@ -7,5 +7,6 @@
 	"init_xml" : [],
 	"demo_xml" : [],
 	"update_xml" : ["subscription_view.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
