@@ -6,5 +6,6 @@
 	"init_xml" : [],
 	"update_xml" : ["custom_view.xml", "custom_report.xml"],
 	"category" : "Enterprise Specific Modules/Travel Agencies",
-	"active": False
+	"active": False,
+	"installable": False
 }
