@@ -277,8 +277,10 @@ class many2one(_column):
 		# build a dictionary of the form {'id_of_distant_resource': name_of_distant_resource}
 		names = dict(obj.name_get(cr, user, filter(None, res.values()), context))
 		for r in res.keys():
-			if res[r]:
-				res[r] = (res[r], names.get(res[r], False))
+			if res[r] and res[r] in names:
+				res[r] = (res[r], names[res[r]])
+			else:
+				res[r] = False
 		return res
 
 	def set(self, cr, obj_src, id, field, values, user=None, context={}):
@@ -329,6 +331,8 @@ class one2many(_column):
 		return res
 
 	def set(self, cr, obj, id, field, values, user=None, context={}):
+		if not values:
+			return
 		_table = obj.pool.get(self._obj)._table
 		obj = obj.pool.get(self._obj)
 		for act in values:
@@ -387,6 +391,8 @@ class many2many(_column):
 		return res
 
 	def set(self, cr, obj, id, name, values, user=None, context={}):
+		if not values:
+			return
 		obj = obj.pool.get(self._obj)
 		for act in values:
 			if act[0]==0:
@@ -520,19 +526,21 @@ class property(function):
 		obj = self.pool.get(self2._obj)
 		names = dict(obj.name_get(cr, uid, filter(None, res.values()), context))
 		for r in res.keys():
-			if res[r]:
-				res[r] = (res[r], names.get(res[r], False))
+			if res[r] and res[r] in names:
+				res[r] = (res[r], names[res[r]])
+			else:
+				res[r] = False
 		return res
 
 	def _field_get(self, self2, cr, uid, prop):
-		if not self.field_id:
+		if not self.field_id.get(cr.dbname):
 			cr.execute('select id from ir_model_fields where name=%s and model=%s', (prop, self2._name))
 			res = cr.fetchone()
-			self.field_id = res and res[0]
-		return self.field_id
+			self.field_id[cr.dbname] = res and res[0]
+		return self.field_id[cr.dbname]
 
 	def __init__(self, obj_prop, **args):
-		self.field_id = False
+		self.field_id = {}
 		function.__init__(self,
 		  self._fnct_read, False,
 		  self._fnct_write, (obj_prop, ),
