@@ -410,8 +410,9 @@ class orm(object):
 								# set the field to the default value if any
 								if self._defaults.has_key(k):
 									default = self._defaults[k](self, cr, 1, {})
-									cr.execute("UPDATE %s SET %s='%s' WHERE %s is NULL" % (self._table, k, default, k))
-									cr.commit()
+									if not (default is False):
+										cr.execute("UPDATE %s SET %s='%s' WHERE %s is NULL" % (self._table, k, default, k))
+										cr.commit()
 								# add the NOT NULL constraint
 								try:
 									cr.execute("ALTER TABLE %s ALTER COLUMN %s SET NOT NULL" % (self._table, k))
@@ -641,6 +642,9 @@ class orm(object):
 			except Exception, e:
 				cr.rollback()
 				return (-1, res, e[0], warning)
+			except:
+				cr.rollback()
+				return (-1, res, 'Exception', warning)
 			done += 1
 		#
 		# TODO: Send a request with the result and multi-thread !
@@ -1268,13 +1272,14 @@ class orm(object):
 						qu1.append('(%s.%s %s %s)' % (table._table, x[0], x1, table._columns[x[0]]._symbol_set[0]))
 			elif x[1]=='in':
 				if len(x[2])>0:
-					todel = False
+					todel = []
 					for xitem in range(len(x[2])):
 						if x[2][xitem]==False and isinstance(x[2][xitem],bool):
-							todel = xitem
-							del x[2][xitem]
+							todel.append(xitem)
+					for xitem in todel[::-1]:
+						del x[2][xitem]
 					if x[0]=='id':
-						qu1.append('(id=any(array[%s]))' % (','.join(['%d'] * len(x[2])),))
+						qu1.append('(%s.id=any(array[%s]))' % (table._table, ','.join(['%d'] * len(x[2])),))
 					else:
 						qu1.append('(%s.%s in (%s))' % (table._table, x[0], ','.join([table._columns[x[0]]._symbol_set[0]]*len(x[2]))))
 					if todel:
