@@ -49,10 +49,10 @@ class except_osv(Exception):
 		self.args = (exc_type,name)
 
 class osv_pool(netsvc.Service):
-	obj_pool = {}
-	module_object_list = {}
 
 	def __init__(self):
+		self.obj_pool = {}
+		self.module_object_list = {}
 		self.created = []
 		self._sql_error = {}
 		netsvc.Service.__init__(self, 'object_proxy', audience='')
@@ -96,10 +96,11 @@ class osv_pool(netsvc.Service):
 
 
 	def execute(self, db, uid, obj, method, *args, **kw):
-		cr = pooler.get_db(db).cursor()
+		db, pool = pooler.get_db_and_pool(db)
+		cr = db.cursor()
 		try:
 			try:
-				res = self.execute_cr(cr, uid, obj, method, *args, **kw)
+				res = pool.execute_cr(cr, uid, obj, method, *args, **kw)
 				cr.commit()
 			except Exception:
 				cr.rollback()
