@@ -105,10 +105,12 @@ def in_modules(object_name, modules):
 	module = module_dict.get(module, module)
 	return module in modules
 
-def trans_generate(lang, modules):
-	pool = pooler.get_pool(tools.config['db_name'])
+def trans_generate(lang, modules, dbname=None):
+	if not dbname:
+		dbname=tools.config['db_name']
+	pool = pooler.get_pool(dbname)
 	trans_obj = pool.get('ir.translation')
-	cr = pooler.get_db(tools.config['db_name']).cursor()
+	cr = pooler.get_db(dbname).cursor()
 	uid = 1
 	l = pool.obj_pool.items()
 	l.sort()
@@ -181,7 +183,7 @@ def trans_generate(lang, modules):
 				if 'result' in state_def:
 					result = state_def['result']
 					if result['type'] != 'form':
-						break
+						continue
 
 					name = obj.wiz_name + ',' + state_name
 
@@ -236,13 +238,14 @@ def trans_generate(lang, modules):
 
 def trans_load(db_name, filename, lang, strict=False):
 	logger = netsvc.Logger()
+	data=''
 	try:
 		data=file(filename,'r').read().split('\n')
 	except IOError:
 		logger.notifyChannel("init", netsvc.LOG_ERROR, "couldn't read file")
 	return trans_load_data(db_name, data, lang, strict=False)
 
-def trans_load_data(db_name, data, lang, strict=False):
+def trans_load_data(db_name, data, lang, strict=False, lang_name=None):
 	logger = netsvc.Logger()
 	logger.notifyChannel("init", netsvc.LOG_INFO, 'loading translation file for language %s' % (lang))
 	pool = pooler.get_pool(db_name)
@@ -254,10 +257,11 @@ def trans_load_data(db_name, data, lang, strict=False):
 
 		ids = lang_obj.search(cr, uid, [('code','=',lang)])
 		if not ids:
-			lang_name=lang
-			languages=tools.get_languages()
-			if lang in languages:
-				lang_name=languages[lang]
+			if not lang_name:
+				lang_name=lang
+				languages=tools.get_languages()
+				if lang in languages:
+					lang_name=languages[lang]
 			ids = lang_obj.create(cr, uid, {'code':lang, 'name':lang_name, 'translatable':1})
 		else:
 			lang_obj.write(cr, uid, ids, {'translatable':1})
